@@ -37,11 +37,38 @@ import datetime
 from decimal import Decimal
 
 
-__all__ = ['Customer', 'EJTransaction', 'EJCustomer', 'EJItem', 'EJPromotion',
-           'EJDiscount', 'EJTax', 'ChargeHistory']
+__all__ = [
+    u'Item', u'Customer', u'NegativeCheck', u'InstoreCharge', u'ChargeHistory',
+    u'EJTransaction', u'EJCustomer', u'EJItem', u'EJPromotion', u'EJDiscount', u'EJTax',
+    ]
 
 
-Base = declarative_base()
+class BaseObject(object):
+    """
+    Superclass for the declarative base.
+    """
+
+    def __init__(self, **kwargs):
+        """
+        Custom constructor to provide default attribute values.
+
+        This leverages column defaults in order to initially populate the
+        object instance.
+        """
+        for attr in object_mapper(self).column_attrs:
+            if attr.key not in kwargs:
+                column = attr.columns[0]
+                if column.default:
+                    setattr(self, attr.key, column.default.arg)
+        # Kwargs always overrides default values.  This is especially necessary
+        # since some attributes are "raw" columns and others use property
+        # function wrappers.  Therefore the property will be set after the
+        # column has provided the default value.
+        for key, value in kwargs.iteritems():
+            setattr(self, key, value)
+    
+
+Base = declarative_base(cls=BaseObject, constructor=None)
 
 
 # NOTE: The following comments and code appeared to be necessary at some point,
@@ -59,6 +86,345 @@ Base = declarative_base()
 #     return SA_String(*args, **kwargs)
 
 
+def date_property(column, fmt):
+    """
+    Establish a date property for the given column.
+    """
+    
+    def getter(self):
+        value = getattr(self, column)
+        if value is None:
+            return None
+        if value == '000000':
+            return None
+        return datetime.datetime.strptime(value, fmt).date()
+
+    def setter(self, value):
+        if value is None:
+            setattr(self, column, '000000')
+        elif isinstance(value, basestring):
+            setattr(self, column, value)
+        else:
+            setattr(self, column, value.strftime(fmt))
+
+    return property(getter, setter)
+
+
+def decimal_property(column, length):
+    """
+    Establish a decimal property for the given column.
+    """
+
+    def getter(self):
+        value = getattr(self, column)
+        if value is None:
+            return None
+        return Decimal('{0}.{1}'.format(value[:-2], value[-2:]))
+
+    def setter(self, value):
+        if value is None:
+            setattr(self, column, None)
+        elif isinstance(value, basestring):
+            setattr(self, column, value)
+        else:
+            fmt = '{{0:0{0}d}}'.format(length)
+            setattr(self, column, fmt.format(int(value * 100)))
+
+    return property(getter, setter)
+
+
+def int_property(column, length):
+    """
+    Establish an integer property for the given column.
+    """
+
+    def getter(self):
+        value = getattr(self, column)
+        if value is None:
+            return 0
+        return int(value)
+
+    def setter(self, value):
+        if value is None:
+            value = 0
+        else:
+            value = int(value)
+        fmt = '{{0:0{0}d}}'.format(length)
+        setattr(self, column, fmt.format(value))
+
+    return property(getter, setter)
+
+
+def time_property(column, fmt):
+    """
+    Establish a time property for the given column.
+    """
+    
+    def getter(self):
+        value = getattr(self, column)
+        if value is None:
+            return None
+        return datetime.datetime.strptime(value, fmt).time()
+
+    def setter(self, value):
+        if value is None:
+            setattr(self, column, None)
+        else:
+            setattr(self, column, value.strftime(fmt))
+
+    return property(getter, setter)
+
+
+class Item(Base):
+    """
+    Represents an item (product).
+    """
+    __tablename__ = u'Item'
+
+    UPC = Column(
+        u'UPC', String(length=20), primary_key=True, nullable=False)
+
+    POSDescription = Column(
+        u'POSDescription', String(length=16), nullable=False)
+
+    Department = Column(
+        u'Department', String(length=4), nullable=False)
+
+    SubDepartment = Column(
+        u'SubDepartment', String(length=4), nullable=False)
+
+    ItemType = Column(
+        u'ItemType', String(length=1), nullable=False)
+
+    UnitPrice = Column(
+        u'UnitPrice', String(length=6), nullable=False)
+
+    SplitQuantity = Column(
+        u'SplitQuantity', String(length=2), nullable=False)
+
+    SplitPrice = Column(
+        u'SplitPrice', String(length=6), nullable=False)
+
+    FoodStamp = Column(
+        u'FoodStamp', String(length=1), nullable=False)
+
+    Tax1 = Column(
+        u'Tax1', String(length=1), nullable=False)
+
+    Tax2 = Column(
+        u'Tax2', String(length=1), nullable=False)
+
+    Tax3 = Column(
+        u'Tax3', String(length=1), nullable=False)
+
+    Discount1 = Column(
+        u'Discount1', String(length=1), nullable=False)
+
+    Discount2 = Column(
+        u'Discount2', String(length=1), nullable=False)
+
+    FrequentShopper = Column(
+        u'FrequentShopper', String(length=1), nullable=False)
+
+    EnforceQuantity = Column(
+        u'EnforceQuantity', String(length=1), nullable=False)
+
+    LimitedQuantity = Column(
+        u'LimitedQuantity', String(length=2), nullable=False)
+
+    LimitedPrice = Column(
+        u'LimitedPrice', String(length=6), nullable=False)
+
+    BottleLink = Column(
+        u'BottleLink', String(length=2), nullable=False)
+
+    MixMatch = Column(
+        u'MixMatch', String(length=4), nullable=False)
+
+    ReportCode = Column(
+        u'ReportCode', String(length=4), nullable=False)
+
+    AdLevel = Column(
+        u'AdLevel', String(length=1), nullable=False)
+
+    VisualVerify = Column(
+        u'VisualVerify', String(length=1), nullable=False)
+
+    ReceiptCouponNumber = Column(
+        u'ReceiptCouponNumber', String(length=4), nullable=False)
+
+    RestrictSale = Column(
+        u'RestrictSale', String(length=1), nullable=False)
+
+    UnitCost = Column(
+        u'UnitCost', String(length=9), nullable=False)
+
+    CaseCost = Column(
+        u'CaseCost', String(length=9), nullable=False)
+
+    CaseQuantity = Column(
+        u'CaseQuantity', String(length=4), nullable=False)
+
+    CommodityCode = Column(
+        u'CommodityCode', String(length=8), nullable=False)
+
+    DateTimeModified = Column(
+        u'DateTimeModified', String(length=14), nullable=False)
+
+    WIC = Column(
+        u'WIC', String(length=1), nullable=False)
+
+    ElectronicCoupon = Column(
+        u'ElectronicCoupon', String(length=1), nullable=False)
+
+    AuditFlag = Column(
+        u'AuditFlag', String(length=1), nullable=False)
+
+    VendorNumber = Column(
+        u'VendorNumber', String(length=8), nullable=False)
+
+    ItemNumber = Column(
+        u'ItemNumber', String(length=13), nullable=False)
+
+    ModifiedByBatch = Column(
+        u'ModifiedByBatch', String(length=4), nullable=False)
+
+    Seasonal = Column(
+        u'Seasonal', String(length=1), nullable=False)
+
+    AdFlag = Column(
+        u'AdFlag', String(length=1), nullable=False)
+
+    PackSize = Column(
+        u'PackSize', String(length=4), nullable=False)
+
+    UnitSize = Column(
+        u'UnitSize', String(length=9), nullable=False)
+
+    UnitMeasure = Column(
+        u'UnitMeasure', String(length=4), nullable=False)
+
+    Aisle = Column(
+        u'Aisle', String(length=3), nullable=False)
+
+    Shelf = Column(
+        u'Shelf', String(length=3), nullable=False)
+
+    Location = Column(
+        u'Location', String(length=3), nullable=False)
+
+    TagStockNumber = Column(
+        u'TagStockNumber', String(length=3), nullable=False)
+
+    TagQuantity = Column(
+        u'TagQuantity', String(length=3), nullable=False)
+
+    FamilyCode1 = Column(
+        u'FamilyCode1', String(length=3), nullable=False)
+
+    FamilyCode2 = Column(
+        u'FamilyCode2', String(length=3), nullable=False)
+
+    TareCode = Column(
+        u'TareCode', String(length=2), nullable=False)
+
+    Weight = Column(
+        u'Weight', String(length=6), nullable=False)
+
+    AdjectivePriceCode = Column(
+        u'AdjectivePriceCode', String(length=4), nullable=False)
+
+    Points = Column(
+        u'Points', String(length=6), nullable=False)
+
+    BonusPoints = Column(
+        u'BonusPoints', String(length=6), nullable=False)
+
+    FreeItem = Column(
+        u'FreeItem', String(length=1), nullable=False)
+
+    ExcludeFromMinPur = Column(
+        u'ExcludeFromMinPur', String(length=1), nullable=False)
+
+    BOFDescription = Column(
+        u'BOFDescription', String(length=30), nullable=False)
+
+    GiftCard = Column(
+        u'GiftCard', String(length=1), nullable=False)
+
+    PriceOverride = Column(
+        u'PriceOverride', String(length=1), nullable=False)
+
+    LikeCode = Column(
+        u'LikeCode', String(length=20), nullable=False)
+
+    PriceEndDate = Column(
+        u'PriceEndDate', String(length=8), nullable=False)
+
+    UnitSizeDescription = Column(
+        u'UnitSizeDescription', String(length=9), nullable=False)
+
+    BaseUnitPrice = Column(
+        u'BaseUnitPrice', String(length=6), nullable=False)
+
+    BaseSplitQuantity = Column(
+        u'BaseSplitQuantity', String(length=2), nullable=False)
+
+    BaseSplitPrice = Column(
+        u'BaseSplitPrice', String(length=6), nullable=False)
+
+    BaseTareCode = Column(
+        u'BaseTareCode', String(length=2), nullable=False)
+
+    BaseWeight = Column(
+        u'BaseWeight', String(length=6), nullable=False)
+
+    BaseLimitQuantity = Column(
+        u'BaseLimitQuantity', String(length=2), nullable=False)
+
+    BaseLimitPrice = Column(
+        u'BaseLimitPrice', String(length=6), nullable=False)
+
+    BaseLikeCode = Column(
+        u'BaseLikeCode', String(length=20), nullable=False)
+
+    BaseBottleLink = Column(
+        u'BaseBottleLink', String(length=2), nullable=False)
+
+    BaseMixMatch = Column(
+        u'BaseMixMatch', String(length=4), nullable=False)
+
+    BaseItemType = Column(
+        u'BaseItemType', String(length=1), nullable=False)
+
+    AllowManualWeight = Column(
+        u'AllowManualWeight', String(length=1), nullable=False)
+
+    PromoID = Column(
+        u'PromoID', String(length=20), nullable=False)
+
+    UOMCompareID = Column(
+        u'UOMCompareID', String(length=4), nullable=False)
+
+    Rx = Column(
+        u'Rx', String(length=1), nullable=False)
+
+    NonRxHC = Column(
+        u'NonRxHC', String(length=1), nullable=False)
+
+    CVV = Column(
+        u'CVV', String(length=1), nullable=False)
+
+    Blanks = Column(
+        u'Blanks', String(length=173), nullable=True)
+
+    def __repr__(self):
+        return u'Item(UPC={0})'.format(repr(self.UPC))
+
+    def __unicode__(self):
+        return unicode(self.POSDescription)
+
+
 class Customer(Base):
     """
     Represents a customer.
@@ -96,21 +462,7 @@ class Customer(Base):
     _DateOpened = Column(
         'DateOpened', String(length=6), nullable=False, default='000000')
 
-    def _get_date_opened(self):
-        if self._DateOpened is None:
-            return None
-        if self._DateOpened == '000000':
-            return None
-        return datetime.datetime.strptime(self._DateOpened, '%m%d%y').date()
-
-    def _set_date_opened(self, date):
-        if date is None:
-            self._DateOpened = '000000'
-        else:
-            self._DateOpened = date.strftime('%m%d%y')
-
-    date_opened = property(
-        _get_date_opened, _set_date_opened)
+    date_opened = date_property('_DateOpened', '%m%d%y')
 
     tax_exempt_code = Column(
         'TaxExemptCode', String(length=12), nullable=False, default='000000000000')
@@ -121,26 +473,12 @@ class Customer(Base):
     _NumVisitsTD = Column(
         'NumVisitsTD', String(length=3), nullable=False, default='000')
 
-    def _get_number_visits_to_date(self):
-        return int(self._NumVisitsTD)
-
-    def _set_number_visits_to_date(self, visits):
-        self._NumVisitsTD = '{0:03d}'.format(int(visits))
-
-    number_visits_to_date = property(
-        _get_number_visits_to_date, _set_number_visits_to_date)
+    number_visits_to_date = int_property('_NumVisitsTD', 3)
 
     _NumVisitsPTD = Column(
         'NumVisitsPTD', String(length=3), nullable=False, default='000')
 
-    def _get_number_visits_period_to_date(self):
-        return int(self._NumVisitsPTD)
-
-    def _set_number_visits_period_to_date(self, visits):
-        self._NumVisitsPTD = '{0:03d}'.format(int(visits))
-
-    number_visits_period_to_date = property(
-        _get_number_visits_period_to_date, _set_number_visits_period_to_date)
+    number_visits_period_to_date = int_property('_NumVisitsPTD', 3)
 
     purchase_amount_to_date = Column(
         'PurchaseAmountTD', String(length=9), nullable=False, default='000000000')
@@ -151,21 +489,7 @@ class Customer(Base):
     _DOLPurchase = Column(
         'DOLPurchase', String(length=6), nullable=False, default='000000')
 
-    def _get_date_of_last_purchase(self):
-        if self._DOLPurchase is None:
-            return None
-        if self._DOLPurchase == '000000':
-            return None
-        return datetime.datetime.strptime(self._DOLPurchase, '%m%d%y').date()
-
-    def _set_date_of_last_purchase(self, date):
-        if date is None:
-            self._DOLPurchase = '000000'
-        else:
-            self._DOLPurchase = date.strftime('%m%d%y')
-
-    date_of_last_purchase = property(
-        _get_date_of_last_purchase, _set_date_of_last_purchase)
+    date_of_last_purchase = date_property('_DOLPurchase', '%m%d%y')
 
     comments = Column(
         'Comments', String(length=30), nullable=False, default='')
@@ -179,34 +503,12 @@ class Customer(Base):
     _FSDollarsTD = Column(
         'FSDollarsTD', String(length=9), nullable=False, default='000000000')
 
-    def _get_frequent_shopper_dollars_to_date(self):
-        return Decimal('{0}.{1}'.format(self._FSDollarsTD[:-2], self._FSDollarsTD[-2:]))
-
-    def _set_frequent_shopper_dollars_to_date(self, dollars):
-        if isinstance(dollars, basestring):
-            dollars = int(dollars)
-        else:
-            dollars = int(dollars * 100)
-        self._FSDollarsTD = '{0:09d}'.format(dollars)
-
-    frequent_shopper_dollars_to_date = property(
-        _get_frequent_shopper_dollars_to_date, _set_frequent_shopper_dollars_to_date)
+    frequent_shopper_dollars_to_date = decimal_property('_FSDollarsTD', 9)
 
     _FSDollarsPTD = Column(
         'FSDollarsPTD', String(length=9), nullable=False, default='000000000')
 
-    def _get_frequent_shopper_dollars_period_to_date(self):
-        return Decimal('{0}.{1}'.format(self._FSDollarsPTD[:-2], self._FSDollarsPTD[-2:]))
-
-    def _set_frequent_shopper_dollars_period_to_date(self, dollars):
-        if isinstance(dollars, basestring):
-            dollars = int(dollars)
-        else:
-            dollars = int(dollars * 100)
-        self._FSDollarsPTD = '{0:09d}'.format(dollars)
-
-    frequent_shopper_dollars_period_to_date = property(
-        _get_frequent_shopper_dollars_period_to_date, _set_frequent_shopper_dollars_period_to_date)
+    frequent_shopper_dollars_period_to_date = decimal_property('_FSDollarsPTD', 9)
 
     number_checks_today = Column(
         'NumChecksToday', String(length=1), nullable=False, default='0')
@@ -281,25 +583,6 @@ class Customer(Base):
     blanks = Column(
         'Blanks', String(length=12), nullable=True, default='000000000000')
 
-    def __init__(self, **kwargs):
-        """
-        Custom constructor to provide default attribute values.
-
-        This leverages column defaults in order to initially populate the
-        object instance.
-        """
-        for attr in object_mapper(self).column_attrs:
-            if attr.key not in kwargs:
-                column = attr.columns[0]
-                if column.default:
-                    setattr(self, attr.key, column.default.arg)
-        # Kwargs always overrides default values.  This is especially necessary
-        # since some attributes are "raw" columns and others use property
-        # function wrappers.  Therefore the property will be set after the
-        # column has provided the default value.
-        for key, value in kwargs.iteritems():
-            setattr(self, key, value)
-
     def __repr__(self):
         return "Customer(account_number={0})".format(
             repr(self.account_number))
@@ -427,6 +710,105 @@ extended_proxy('drivers_license_state')
 extended_proxy('alternate_lookup')
 
 
+class NegativeCheck(Base):
+    """
+    Represents a "negative check" record.
+    """
+
+    __tablename__ = 'NegativeCheck'
+
+    account_number = Column(
+        'AccountNumber', String(length=20), primary_key=True, nullable=False)
+
+    last_name = Column(
+        'LastName', String(length=25), nullable=False)
+
+    first_name = Column(
+        'FirstName', String(length=25), nullable=False)
+
+    address = Column(
+        'Address', String(length=25), nullable=False)
+
+    city = Column(
+        'City', String(length=15), nullable=False)
+
+    state = Column(
+        'State', String(length=2), nullable=False)
+
+    zipcode = Column(
+        'Zipcode', String(length=9), nullable=False)
+
+    phone_number = Column(
+        'PhoneNumber', String(length=10), nullable=False)
+
+    social_security_number = Column(
+        'SSNumber', String(length=9), nullable=False)
+
+    _DateOpened = Column(
+        'DateOpened', String(length=6), nullable=False)
+
+    date_opened = date_property('_DateOpened', '%m%d%y')
+
+    tax_exempt_code = Column(
+        'TaxExemptCode', String(length=12), nullable=False)
+
+    checking_account_number = Column(
+        'CheckingAcctNum', String(length=20), nullable=False)
+
+    _NumChecksTendered = Column(
+        'NumChecksTendered', String(length=3), nullable=False)
+
+    checks_tendered_count = int_property('_NumChecksTendered', 3)
+
+    _NumNSFChecks = Column(
+        'NumNSFChecks', String(length=3), nullable=False)
+
+    checks_nsf_count = int_property('_NumNSFChecks', 3)
+
+    _ChecksTenderedAmount = Column(
+        'ChecksTenderedAmount', String(length=7), nullable=False)
+
+    checks_tendered_amount = decimal_property('_ChecksTenderedAmount', 7)
+
+    _NSFChecksAmount = Column(
+        'NSFChecksAmount', String(length=7), nullable=False)
+
+    checks_nsf_amount = decimal_property('_NSFChecksAmount', 7)
+
+    _DateOfLastPurchase = Column(
+        'DateOfLastPurchase', String(length=6), nullable=False)
+
+    date_of_last_purchase = date_property('_DateOfLastPurchase', '%m%d%y')
+
+    comments = Column(
+        'Comments', String(length=30), nullable=False)
+
+    _OverrideCount = Column(
+        'OverrideCount', String(length=3), nullable=False)
+
+    override_count = int_property('_OverrideCount', 3)
+
+    account_status = Column(
+        'AccountStatus', String(length=1), nullable=False)
+
+    transit_routing_number = Column(
+        'TransitRoutingNumber', String(length=9), nullable=False)
+
+    blanks = Column(
+        'Blanks', String(length=66), nullable=True)
+
+    def __repr__(self):
+        return "NegativeCheck(account_number={0})".format(
+            repr(self.account_number))
+
+
+NegativeCheck.customer = relationship(
+    Customer,
+    primaryjoin=Customer.account_number == NegativeCheck.account_number,
+    foreign_keys=[Customer.account_number],
+    uselist=False)
+
+
 class EJTransaction(Base):
     """
     Represents an electronic journal transaction.
@@ -941,6 +1323,83 @@ EJTransaction.taxes = relationship(
     backref='transaction')
 
 
+class InstoreCharge(Base):
+    """
+    Represents an in-store charge account.
+    """
+
+    __tablename__ = 'InstoreCharge'
+
+    account_number = Column(
+        'ACCOUNTNUMBER', String(length=12), primary_key=True, nullable=False)
+
+    _DATEOPENED = Column(
+        'DATEOPENED', String(length=6), nullable=False, default='000000')
+
+    date_opened = date_property('_DATEOPENED', '%m%d%y')
+
+    _CREDITLIMIT = Column(
+        'CREDITLIMIT', String(length=6), nullable=False, default='000000')
+
+    credit_limit = decimal_property('_CREDITLIMIT', 6)
+
+    credit_status = Column(
+        'CREDITSTATUS', String(length=1), nullable=False, default='0')
+
+    _DATEOFLASTPAYMENT = Column(
+        'DATEOFLASTPAYMENT', String(length=6), nullable=False, default='000000')
+
+    date_of_last_payment = date_property('_DATEOFLASTPAYMENT', '%y%m%d')
+
+    _AMOUNTOFLASTPAYMENT = Column(
+        'AMOUNTOFLASTPAYMENT', String(length=8), nullable=False, default='00000000')
+
+    amount_of_last_payment = decimal_property('_AMOUNTOFLASTPAYMENT', 8)
+
+    _CURRENTBALANCE = Column(
+        'CURRENTBALANCE', String(length=8), nullable=False, default='00000000')
+
+    current_balance = decimal_property('_CURRENTBALANCE', 8)
+
+    _PREVIOUSBALANCE = Column(
+        'PREVIOUSBALANCE', String(length=8), nullable=False, default='00000000')
+
+    previous_balance = decimal_property('_PREVIOUSBALANCE', 8)
+
+    _PAGENUMBER = Column(
+        'PAGENUMBER', String(length=2), nullable=False, default='00')
+
+    page_number = int_property('_PAGENUMBER', 2)
+
+    _LINENUMBER = Column(
+        'LINENUMBER', String(length=2), nullable=False, default='00')
+
+    line_number = int_property('_LINENUMBER', 2)
+
+    finance_charges = Column(
+        'FINANCECHARGES', String(length=1), nullable=False, default='0')
+
+    apr = Column(
+        'APR', String(length=4), nullable=False, default='0000')
+
+    blanks = Column(
+        'BLANKS', String(length=34), nullable=True, default='0000000000000000000000000000000000')
+
+    update_flag = Column(
+        'UPDATEFLAG', String(length=1), nullable=False, default='0')
+
+    def __repr__(self):
+        return "InstoreCharge(account_number={0})".format(
+            repr(self.account_number))
+
+
+InstoreCharge.customer = relationship(
+    Customer,
+    primaryjoin=Customer.account_number == InstoreCharge.account_number,
+    foreign_keys=[Customer.account_number],
+    uselist=False)
+
+
 class ChargeHistory(Base):
     """
     Represents a charge event within a customer account's history.
@@ -957,43 +1416,18 @@ class ChargeHistory(Base):
     _BUSINESSDATE = Column(
         'BUSINESSDATE', String(length=6), nullable=True)
 
-    def _get_business_date(self):
-        if self._BUSINESSDATE is None:
-            return None
-        return datetime.datetime.strptime(self._BUSINESSDATE, '%y%m%d').date()
-
-    def _set_business_date(self, date):
-        if date is None:
-            self._BUSINESSDATE = None
-        else:
-            self._BUSINESSDATE = date.strftime('%y%m%d')
-
-    business_date = property(
-        _get_business_date, _set_business_date)
+    business_date = date_property('_BUSINESSDATE', '%y%m%d')
 
     _BUSINESSTIME = Column(
         'BUSINESSTIME', String(length=4), nullable=True)
 
-    def _get_business_time(self):
-        if self._BUSINESSTIME is None:
-            return None
-        return datetime.datetime.strptime(self._BUSINESSTIME, '%H%M').time()
-
-    def _set_business_time(self, time):
-        if time is None:
-            self._BUSINESSTIME = None
-        else:
-            self._BUSINESSTIME = time.strftime('%H%M')
-
-    business_time = property(
-        _get_business_time, _set_business_time)
+    business_time = time_property('_BUSINESSTIME', '%H%M')
 
     @property
     def occurred(self):
         """
         The date and time when the charge occurred.
         """
-
         if self.business_date is None:
             return self.business_time
         if self.business_time is None:
@@ -1015,19 +1449,7 @@ class ChargeHistory(Base):
     _AMOUNT = Column(
         'AMOUNT', String(length=8), nullable=True)
 
-    def _get_amount(self):
-        if self._AMOUNT is None:
-            return None
-        return Decimal('{0}.{1}'.format(self._AMOUNT[:-2], self._AMOUNT[-2:]))
-
-    def _set_amount(self, amount):
-        if amount is None:
-            self._AMOUNT = None
-        else:
-            self._AMOUNT = '{0:08d}'.format(int(amount * 100))
-
-    amount = property(
-        _get_amount, _set_amount)
+    amount = decimal_property('_AMOUNT', 8)
 
     export_flag = Column(
         'EXPORTFLAG', String(length=1), nullable=True)
